Documentation.addTranslations({"locale": "hr", "messages": {"%(filename)s &#8212; %(docstitle)s": "%(filename)s &#8212; %(docstitle)s", "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "&#169; <a href=\"%(path)s\">Sva prava zadr\u017eana</a> %(copyright)s.", "&#169; Copyright %(copyright)s.": "&#169; Sva prava zadr\u017eana %(copyright)s.", ", in ": ", u ", "About these documents": "O ovim dokumentima", "Automatically generated list of changes in version %(version)s": "Automatski generirani popis promjena u verziji %(version)s", "C API changes": "C API promjene", "Changes in Version %(version)s &#8212; %(docstitle)s": "Promjene u verziji %(version)s &#8212; %(docstitle)s", "Collapse sidebar": "Sakrij pomo\u0107nu traku", "Complete Table of Contents": "Detaljni sadr\u017eaj", "Contents": "Sadr\u017eaj", "Copyright": "Sva prava zadr\u017eana", "Created using <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "Izra\u0111eno sa <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.", "Expand sidebar": "Poka\u017ei pomo\u0107nu traku", "Full index on one page": "Potpun indeks na jednoj stranici", "General Index": "Opceniti abecedni indeks", "Global Module Index": "Op\u0107eniti popis modula", "Go": "Tra\u017ei", "Hide Search Matches": "Sakrij rezultate pretrage", "Index": "Abecedni popis", "Index &ndash; %(key)s": "Index &ndash; %(key)s", "Index pages by letter": "Indeksiraj stranice po slovu", "Indices and tables:": "Kazala i tablice:", "Last updated on %(last_updated)s.": "Zadnji put a\u017eurirano %(last_updated)s.", "Library changes": "Promjene lib-ova", "Navigation": "Navigacija", "Next topic": "Sljede\u0107a tema", "Other changes": "Ostale promjene", "Overview": "Pregled", "Permalink to this definition": "Link na tu definiciju", "Permalink to this headline": "Link na taj naslov", "Please activate JavaScript to enable the search\n    functionality.": "Molimo omogu\u0107ite JavaScript\n    za djelovanje tra\u017eilice.", "Preparing search...": "Priprema pretrage...", "Previous topic": "Prija\u0161nja tema", "Quick search": "Brzo pretra\u017eivanje", "Search": "Tra\u017ei", "Search Page": "Tra\u017eilica", "Search Results": "Rezultati pretrage", "Search finished, found %s page(s) matching the search query.": "Pretraga zavr\u0161ena, prona\u0111eno %s stranica.", "Search within %(docstitle)s": "Tra\u017ei izme\u0111u %(docstitle)s", "Searching": "Pretra\u017eivanje", "Searching for multiple words only shows matches that contain\n    all words.": "", "Show Source": "Prika\u017ei izvorni kod", "Table of Contents": "", "This Page": "Trenutna stranica", "Welcome! This is": "Dobro do\u0161li! Ovo je", "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "Zadanim uvjetima nije prona\u0111en dokument. Molim provjerite to\u010dnost upisanih rije\u010di i odabir ozna\u010denih kategija.", "all functions, classes, terms": "sve funkcije, razredi, izrazi", "can be huge": "mo\u017ee biti ogromno", "last updated": "posljednja promjena", "lists all sections and subsections": "prika\u017ei sve sekcije i podsekcije", "next chapter": "sljede\u0107e poglavlje", "previous chapter": "Prija\u0161nje poglavlje", "quick access to all modules": "brz dostup do svih modula", "search": "tra\u017ei", "search this documentation": "tra\u017ei po dokumentaciji", "the documentation for": "dokumentacija za"}, "plural_expr": "n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2"});