Documentation.addTranslations({"locale": "eu", "messages": {"%(filename)s &#8212; %(docstitle)s": "", "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "", "&#169; Copyright %(copyright)s.": "", ", in ": "", "About these documents": "Dokumentu hauen inguruan", "Automatically generated list of changes in version %(version)s": "Automatikoki sortutako %(version)s bertsioaren aldaketen zerrenda", "C API changes": "C API aldaketak", "Changes in Version %(version)s &#8212; %(docstitle)s": "", "Collapse sidebar": "Alboko barra tolestu", "Complete Table of Contents": "Eduki taula osoa", "Contents": "Edukiak", "Copyright": "Copyright", "Created using <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "<a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s erabiliz sortutakoa.", "Expand sidebar": "Alboko barra luzatu", "Full index on one page": "Indize guztia orri batean", "General Index": "Indize orokorra", "Global Module Index": "Modulu indize globala", "Go": "Joan", "Hide Search Matches": "Bilaketa bat-etortzeak ezkutatu", "Index": "Indizea", "Index &ndash; %(key)s": "Indizea &ndash; %(key)s", "Index pages by letter": "Indize orriak hizkika", "Indices and tables:": "Indizeak eta taulak:", "Last updated on %(last_updated)s.": "Azken aldaketa: %(last_updated)s.", "Library changes": "Liburutegi aldaketak", "Navigation": "Nabigazioa", "Next topic": "Hurrengo gaia", "Other changes": "Beste aldaketak", "Overview": "Gainbegirada", "Permalink to this definition": "Definizio honetarako esteka iraunkorra", "Permalink to this headline": "Goiburu honetarako esteka iraunkorra", "Please activate JavaScript to enable the search\n    functionality.": "Mesedez, gaitu JavaScript-a bilaketa erabili ahal izateko.", "Preparing search...": "", "Previous topic": "Aurreko gaia", "Quick search": "Bilaketa azkarra", "Search": "Bilatu", "Search Page": "Bilaketa orria", "Search Results": "Bilaketa emaitzak", "Search finished, found %s page(s) matching the search query.": "", "Search within %(docstitle)s": "Bilatu %(docstitle)s(e)n", "Searching": "", "Searching for multiple words only shows matches that contain\n    all words.": "", "Show Source": "Iturburua ikusi", "Table of Contents": "", "This Page": "Orri hau", "Welcome! This is": "", "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "", "all functions, classes, terms": "funtzio, klase, termino guztiak", "can be huge": "handia izan daiteke", "last updated": "", "lists all sections and subsections": "atal eta azpiatal guztiak zerrendatu", "next chapter": "hurrengo kapitulua", "previous chapter": "aurreko kapitulua", "quick access to all modules": "modulu guztietara atzipen azkarra", "search": "bilatu", "search this documentation": "dokumentazio honetan bilatu", "the documentation for": ""}, "plural_expr": "(n != 1)"});