Documentation.addTranslations({"locale": "lv", "messages": {"%(filename)s &#8212; %(docstitle)s": "", "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "", "&#169; Copyright %(copyright)s.": "", ", in ": "", "About these documents": "Par \u0161iem dokumentiem", "Automatically generated list of changes in version %(version)s": "Autom\u0101tiski sagatavots izmai\u0146u saraksts versijai %(version)s", "C API changes": "Izmai\u0146as iek\u0161 C API", "Changes in Version %(version)s &#8212; %(docstitle)s": "", "Collapse sidebar": "Sav\u0113rst s\u0101njoslu", "Complete Table of Contents": "Pilns saturs", "Contents": "Saturs", "Copyright": "Copyright", "Created using <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "Sagatavots izmantojot <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.", "Expand sidebar": "Izplest s\u0101njoslu", "Full index on one page": "Pilns indekss vien\u0101 lappus\u0113", "General Index": "Visp\u0101r\u0113js indekss", "Global Module Index": "Visp\u0101r\u0113js modu\u013cu indekss", "Go": "Izpild\u012bt", "Hide Search Matches": "Pasl\u0113pt atlases v\u0101rdus", "Index": "Indekss", "Index &ndash; %(key)s": "Indekss &ndash; %(key)s", "Index pages by letter": "Lappu\u0161u indekss p\u0113c burtiem", "Indices and tables:": "Indeksi un tabulas:", "Last updated on %(last_updated)s.": "P\u0113d\u0113jas izmai\u0146as %(last_updated)s.", "Library changes": "Bibliot\u0113kas izmai\u0146as", "Navigation": "Navig\u0101cija", "Next topic": "n\u0101ko\u0161a t\u0113ma", "Other changes": "Citas izmai\u0146as", "Overview": "Apskats", "Permalink to this definition": "Past\u0101v\u012bga nor\u0101de uz \u0161o defin\u012bciju", "Permalink to this headline": "Past\u0101v\u012bga nor\u0101de \u0161o virsrakstu", "Please activate JavaScript to enable the search\n    functionality.": "Lai iesp\u0113jotu mekl\u0113\u0161anu, l\u016bdzu aktiviz\u0113t JavaScript.", "Preparing search...": "", "Previous topic": "iepriek\u0161\u0113ja t\u0113ma", "Quick search": "\u0100tra mekl\u0113\u0161ana", "Search": "Mekl\u0113t", "Search Page": "Atlases lapa", "Search Results": "Atlases rezult\u0101ti", "Search finished, found %s page(s) matching the search query.": "", "Search within %(docstitle)s": "Mekl\u0113t iek\u0161 %(docstitle)s", "Searching": "", "Searching for multiple words only shows matches that contain\n    all words.": "", "Show Source": "R\u0101d\u012bt izejas tekstu", "Table of Contents": "", "This Page": "\u0160\u012b lappuse", "Welcome! This is": "", "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "", "all functions, classes, terms": "visas funkcijas, klases un termini", "can be huge": "var b\u016bt milz\u012bgs", "last updated": "", "lists all sections and subsections": "r\u0101da visas sekcijas un apak\u0161sekcijas", "next chapter": "n\u0101ko\u0161a sada\u013ca", "previous chapter": "iepriek\u0161\u0113ja sada\u013ca", "quick access to all modules": "\u0101tra piek\u013cuve visiem moduliem", "search": "mekl\u0113t", "search this documentation": "mekl\u0113t \u0161aj\u0101 dokument\u0101cij\u0101", "the documentation for": ""}, "plural_expr": "(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2)"});