Documentation.addTranslations({"locale": "nb_NO", "messages": {"%(filename)s &#8212; %(docstitle)s": "", "&#169; <a href=\"%(path)s\">Copyright</a> %(copyright)s.": "", "&#169; Copyright %(copyright)s.": "", ", in ": "", "About these documents": "Om disse dokumenter", "Automatically generated list of changes in version %(version)s": "Automatisk generert liste over endringer i versjon %(version)s", "C API changes": "Endringer i C API", "Changes in Version %(version)s &#8212; %(docstitle)s": "", "Collapse sidebar": "Skjul sidepanelet", "Complete Table of Contents": "Komplett Innholdsfortegnelse", "Contents": "Innhold", "Copyright": "Copyright", "Created using <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.": "Lagd med <a href=\"http://sphinx-doc.org/\">Sphinx</a> %(sphinx_version)s.", "Expand sidebar": "Utvid sidepanelet", "Full index on one page": "Hele innholdsfortegnelsen p\u00e5 en side", "General Index": "Hovedindex", "Global Module Index": "Global Modulindex", "Go": "G\u00e5", "Hide Search Matches": "Skjul s\u00f8keresultat", "Index": "Index", "Index &ndash; %(key)s": "Index &ndash; %(key)s", "Index pages by letter": "Innholdsfortegnelse per bokstav", "Indices and tables:": "Index og tabeller", "Last updated on %(last_updated)s.": "Sist oppdatert %(last_updated)s.", "Library changes": "Endringer i biblioteket", "Navigation": "Navigering", "Next topic": "Neste emne", "Other changes": "Andre endringer", "Overview": "Oversikt", "Permalink to this definition": "Permalink til denne definisjonen", "Permalink to this headline": "Permalink til denne oversikten", "Please activate JavaScript to enable the search\n    functionality.": "Vennligst aktiver JavaScript for \u00e5 aktivere s\u00f8k.", "Preparing search...": "", "Previous topic": "Forrige tittel", "Quick search": "Hurtigs\u00f8k", "Search": "S\u00f8k", "Search Page": "S\u00f8keside", "Search Results": "S\u00f8keresultat", "Search finished, found %s page(s) matching the search query.": "", "Search within %(docstitle)s": "S\u00f8k blant %(docstitle)s", "Searching": "", "Searching for multiple words only shows matches that contain\n    all words.": "", "Show Source": "Vis kildekode", "Table of Contents": "", "This Page": "Denne siden", "Welcome! This is": "", "Your search did not match any documents. Please make sure that all words are spelled correctly and that you've selected enough categories.": "", "all functions, classes, terms": "alla funksjoner, klasser, vilk\u00e5r", "can be huge": "kan bli stor", "last updated": "", "lists all sections and subsections": "liste over alle paragrafer og underparagrafer", "next chapter": "neste kapittel", "previous chapter": "Forrige kapittel", "quick access to all modules": "snarvei til alle moduler", "search": "s\u00f8k", "search this documentation": "s\u00f8k i dette dokumentet", "the documentation for": ""}, "plural_expr": "(n != 1)"});